# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['gerapy',
 'gerapy.cmd',
 'gerapy.downloadermiddlewares',
 'gerapy.pipelines',
 'gerapy.server',
 'gerapy.server.core',
 'gerapy.server.core.migrations',
 'gerapy.server.server',
 'gerapy.spiders',
 'gerapy.templates',
 'gerapy.templates.project.module',
 'gerapy.templates.project.module.spiders',
 'gerapy.templates.spiders']

package_data = \
{'': ['*'],
 'gerapy': ['client/*',
            'client/public/*',
            'client/src/*',
            'client/src/assets/images/*',
            'client/src/assets/scss/*',
            'client/src/assets/scss/components/*',
            'client/src/components/*',
            'client/src/langs/*',
            'client/src/layout/*',
            'client/src/utils/*',
            'client/src/views/client/*',
            'client/src/views/home/*',
            'client/src/views/login/*',
            'client/src/views/project/*',
            'client/src/views/task/*'],
 'gerapy.server.core': ['templates/*',
                        'templates/static/css/*',
                        'templates/static/fonts/*',
                        'templates/static/img/*',
                        'templates/static/js/*'],
 'gerapy.templates': ['project/*']}

install_requires = \
['apscheduler>=3.5.1,<=3.7.0',
 'beautifulsoup4>=4.7.0',
 'cryptography>=2.8',
 'django-apscheduler>=0.3.0,<=0.6.0',
 'django-cors-headers>=3.2.0,<=3.7.0',
 'django>=2.2,<3.0',
 'djangorestframework>=3.11.2',
 'furl>=2.1.0',
 'jinja2>=2.11.3',
 'pymongo>=3.9.0',
 'pymysql>=0.7.10',
 'pyppeteer>=0.0.25',
 'pyquery>=1.2.17',
 'python-scrapyd-api>=2.1.2',
 'redis>=2.10.5',
 'requests>=2.20.0',
 'scrapy-redis>=0.6.8',
 'scrapy-splash>=0.7.2',
 'scrapy>=2.7.1',
 'websocket>=0.2.1']

entry_points = \
{'console_scripts': ['gerapy = gerapy.cmd:cmd']}

setup_kwargs = {
    'name': 'gerapy',
    'version': '0.9.12',
    'description': 'Distributed Crawler Management Framework Based on Scrapy, Scrapyd, Scrapyd-Client, Scrapyd-API, Django and Vue.js.',
    'long_description': "# Gerapy\n\n![Build](https://github.com/Gerapy/Gerapy/workflows/build/badge.svg)\n![Read the Docs](https://img.shields.io/readthedocs/gerapy)\n![PyPI - Python Version](https://img.shields.io/badge/python-3.6%2B-blue)\n[![GitHub stars](https://img.shields.io/github/stars/Gerapy/Gerapy)](https://github.com/Gerapy/Gerapy/stargazers)\n![PyPI - Downloads](https://img.shields.io/pypi/dm/gerapy)\n![Docker Pulls](https://img.shields.io/docker/pulls/germey/gerapy)\n![PyPI - License](https://img.shields.io/pypi/l/gerapy)\n\nDistributed Crawler Management Framework Based on Scrapy, Scrapyd, Scrapyd-Client, Scrapyd-API, Django and Vue.js.\n\n## Documentation\n\nDocumentation is available online at [https://docs.gerapy.com/](https://docs.gerapy.com/) and [https://github.com/Gerapy/Docs](https://github.com/Gerapy/Docs).\n\n## Support\n\nGerapy is developed based on Python 3.x. Python 2.x may be supported later.\n\n## Usage\n\nInstall Gerapy by pip:\n\n```bash\npip3 install gerapy\n```\n\nAfter the installation, you need to do these things below to run Gerapy server:\n\nIf you have installed Gerapy successfully, you can use command `gerapy`. If not, check the installation.\n\nFirst use this command to initialize the workspace:\n\n```bash\ngerapy init\n```\n\nNow you will get a folder named `gerapy`. Also you can specify the name of your workspace by this command:\n\n```\ngerapy init <workspace>\n```\n\nThen `cd` to this folder, and run this command to initialize the Database:\n\n```bash\ncd gerapy\ngerapy migrate\n```\n\nNext you need to create a superuser by this command:\n\n```\ngerapy createsuperuser\n```\n\nThen you can runserver by this command:\n\n```bash\ngerapy runserver\n```\n\nThen you can visit [http://localhost:8000](http://localhost:8000) to enjoy it. Also you can vist [http://localhost:8000/admin](http://localhost:8000/admin) to get the admin management backend.\n\nIf you want to run Gerapy in public, just run like this:\n\n```\ngerapy runserver 0.0.0.0:8000\n```\n\nThen it will run with public host and port 8000.\n\nIn Gerapy, You can create a configurable project and then configure and generate code of Scrapy automatically. But this module is unstable, we're trying to refine it.\n\nAlso you can drag your Scrapy Project to `projects` folder. Then refresh web, it will appear in the Project Index Page and comes to un-configurable, but you can edit this project through the web page.\n\nAs for deployment, you can move to Deploy Page. Firstly you need to build your project and add client in the Client Index Page, then you can deploy the project just by clicking button.\n\nAfter the deployment, you can manage the job in Monitor Page.\n\n## Docker\n\nJust run this command:\n\n```\ndocker run -d -v ~/gerapy:/app/gerapy -p 8000:8000 germey/gerapy\n```\n\nThen it will run at port 8000. You can use the temp admin account (username: admin, password: admin) to login. And please change the password later for safety.\n\nCommand Usage:\n\n```\ndocker run -d -v <workspace>:/app/gerapy -p <public_port>:<container_port> germey/gerapy\n```\n\nPlease specify your workspace to mount Gerapy workspace by `-v <workspace>:/app/gerapy` and specify server port by `-p <public_port>:<container_port>`.\n\nIf you run Gerapy by Docker, you can visit Gerapy website such as [http://localhost:8000](http://localhost:8000) and enjoy it, no need to do other initialzation things.\n\n## TodoList\n\n- [x] Add Visual Configuration of Spider with Previewing Website\n- [x] Add Scrapyd Auth Management\n- [x] Add Gerapy Auth Management\n- [x] Add Timed Task Scheduler\n- [ ] Add Visual Configuration of Scrapy\n- [ ] Add Intelligent Analysis of Web Page\n\n## Communication\n\nIf you have any questions or ideas, you can send [Issues](https://github.com/Gerapy/Gerapy/issues) or [Pull Requests](https://github.com/Gerapy/Gerapy/pulls), your suggestions are really import for us, thanks for your contirbution.\n",
    'author': 'Germey',
    'author_email': 'cqc@cuiqingcai.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/Gerapy/Gerapy',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
